InterpolatingComponent — so_pysm_models v0.4.dev210

so_pysm_models:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- so_pysm_models v0.4.dev210 »
- InterpolatingComponent

# InterpolatingComponent

class `so_pysm_models.` `InterpolatingComponent`(path, input_units, target_nside, interpolation_kind='linear', has_polarization=True, pixel_indices=None, mpi_comm=None, verbose=False)

  Bases: `object`

  PySM component interpolating between precomputed maps

  See more details at https://so-pysm-models.readthedocs.io/en/latest/so_pysm_models/models.html

  Parameters: | path : str Path should contain maps named as the frequency in GHz e.g. 20.fits or 20.5.fits or 00100.fits input_units : str Any unit available in PySM (see `pysm.convert_units` e.g. `Jysr`, `MJsr`, `uK_RJ`, `K_CMB`). target_nside : int HEALPix NSIDE of the output maps has_polarization : bool whether or not to simulate also polarization maps pixel_indices : ndarray of ints Outputs partial maps given HEALPix pixel indices in RING ordering mpi_comm : mpi4py communicator See the documentation of pysm.read_map verbose : bool Control amount of output

  Methods Summary

  `get_filenames`(path) |
  `read_map`(freq) |
  `read_map_file`(freq, filename) |
  `signal`(nu, **kwargs) | Return map at given frequency or array of frequencies

  Methods Documentation

  `get_filenames`(path)
  `read_map`(freq)
  `read_map_file`(freq, filename)
  `signal`(nu, **kwargs)

    Return map at given frequency or array of frequencies